package com.trafficparrot.sdk.example.template;

import com.github.jknack.handlebars.Handlebars;
import com.github.jknack.handlebars.Template;
import com.trafficparrot.sdk.example.handlebars.RandomInteger;
import org.junit.Test;

import java.io.IOException;

import static java.util.Collections.emptyMap;
import static org.assertj.core.api.Assertions.assertThat;

public class RandomIntegerTest {

    private final RandomInteger randomInteger = new RandomInteger();
    private final Handlebars handlebars = new Handlebars().registerHelper(randomInteger.getName(), randomInteger);

    @Test
    public void name() {
        assertThat(randomInteger.getName()).isEqualTo("randomInteger");
    }

    @Test
    public void randomIntegerWithNoArguments() throws IOException {
        Template template = handlebars.compileInline("{{ randomInteger }}");
        String apply = template.apply(emptyMap());

        assertThat(Integer.parseInt(apply)).isNotNull();
    }

    @Test
    public void randomIntegerBetweenPositiveAndPositive() throws IOException {
        Template template = handlebars.compileInline("{{ randomInteger 5 10 }}");
        String apply = template.apply(emptyMap());

        assertThat(Integer.parseInt(apply)).isGreaterThanOrEqualTo(5).isLessThanOrEqualTo(10);
    }

    @Test
    public void randomIntegerBetweenZeroAndPositive() throws IOException {
        Template template = handlebars.compileInline("{{ randomInteger 0 5 }}");
        String apply = template.apply(emptyMap());

        assertThat(Integer.parseInt(apply)).isGreaterThanOrEqualTo(0).isLessThanOrEqualTo(5);
    }

    @Test
    public void randomIntegerBetweenNegativeAndZero() throws IOException {
        Template template = handlebars.compileInline("{{ randomInteger -5 0 }}");
        String apply = template.apply(emptyMap());

        assertThat(Integer.parseInt(apply)).isGreaterThanOrEqualTo(-5).isLessThanOrEqualTo(0);
    }

    @Test
    public void randomIntegerBetweenNegativeAndNegative() throws IOException {
        Template template = handlebars.compileInline("{{ randomInteger -10 -5 }}");
        String apply = template.apply(emptyMap());

        assertThat(Integer.parseInt(apply)).isGreaterThanOrEqualTo(-10).isLessThanOrEqualTo(-5);
    }
}